==> haskell-http-api-data-0.5.1-51-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-http-api-data.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-api-data
version:              0.5.1
visibility:           public
id:                   http-api-data-0.5.1-KHPtk8Lg8llBKKAQgMalej
key:                  http-api-data-0.5.1-KHPtk8Lg8llBKKAQgMalej
license:              BSD-3-Clause
maintainer:           Nickolay Kudasov <nickolay.kudasov@gmail.com>
author:               Nickolay Kudasov <nickolay.kudasov@gmail.com>
stability:            unstable
homepage:             http://github.com/fizruk/http-api-data
synopsis:
    Converting to/from HTTP API data like URL pieces, headers and query parameters.

description:
    This package defines typeclasses used for converting Haskell data types to and from HTTP API data.

    Please see README.md

category:             Web
abi:                  b212ce06deca92bc6418cf06ecdbec78
exposed:              True
exposed-modules:
    Web.FormUrlEncoded Web.HttpApiData Web.Internal.FormUrlEncoded
    Web.Internal.HttpApiData

import-dirs:          /usr/lib/ghc-9.2.8/site-local/http-api-data-0.5.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/http-api-data-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-api-data
hs-libraries:         HShttp-api-data-0.5.1-KHPtk8Lg8llBKKAQgMalej
depends:
    attoparsec-0.14.4-HEPxPDNq5mJKRZZEtIXOMd
    attoparsec-iso8601-1.1.0.0-K5cJwT3aBcfCv62yiXaT9Y base-4.16.4.0
    base-compat-0.12.2-5hQPtIjgG5LKnb20qwjRWd bytestring-0.11.4.0
    containers-0.6.5.1 cookie-0.4.6-ATAyIjNvKdDFVIoN0dB8l5
    hashable-1.4.3.0-BWGpbAVaWdFEBuRI2sTyFL
    http-types-0.12.4-IbDJVwQVDeTAnHs7wyLMrJ
    tagged-0.8.8-404YCiJ2agdDxJGZ4AybXg text-1.2.5.0
    time-compat-1.9.6.1-4LKUUS0AewnA698ITHrhN1 transformers-0.5.6.2
    unordered-containers-0.2.20-6SQIi6GiFzoJl2Kyo4GEMQ
    uuid-types-1.0.5.1-DzR0IgzRElQ1K705w84ENs

haddock-interfaces:
    /usr/share/doc/haskell-http-api-data/html/http-api-data.haddock

haddock-html:         /usr/share/doc/haskell-http-api-data/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-api-data-0.5.1-60-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-http-api-data.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-api-data
version:              0.5.1
visibility:           public
id:                   http-api-data-0.5.1-2BBAlVaYv607qWIFAG4oWp
key:                  http-api-data-0.5.1-2BBAlVaYv607qWIFAG4oWp
license:              BSD-3-Clause
maintainer:           Nickolay Kudasov <nickolay.kudasov@gmail.com>
author:               Nickolay Kudasov <nickolay.kudasov@gmail.com>
stability:            unstable
homepage:             http://github.com/fizruk/http-api-data
synopsis:
    Converting to/from HTTP API data like URL pieces, headers and query parameters.

description:
    This package defines typeclasses used for converting Haskell data types to and from HTTP API data.

    Please see README.md

category:             Web
abi:                  cea820bff930735ec7d51e7d3bc6f25c
exposed:              True
exposed-modules:
    Web.FormUrlEncoded Web.HttpApiData Web.Internal.FormUrlEncoded
    Web.Internal.HttpApiData

import-dirs:          /usr/lib/ghc-9.2.8/site-local/http-api-data-0.5.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/http-api-data-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-api-data
hs-libraries:         HShttp-api-data-0.5.1-2BBAlVaYv607qWIFAG4oWp
depends:
    attoparsec-0.14.4-7zFXPvsAeTc17D9FbG47Bq
    attoparsec-iso8601-1.1.0.0-GJ0Uq6PxoZc4i7RFwq7OTO base-4.16.4.0
    base-compat-0.12.2-5hQPtIjgG5LKnb20qwjRWd bytestring-0.11.4.0
    containers-0.6.5.1 cookie-0.4.6-ATAyIjNvKdDFVIoN0dB8l5
    hashable-1.4.4.0-KJ184tiZpE52U0PEHxyV1r
    http-types-0.12.4-4jA7skhyc4O1mTcupRz8pv
    tagged-0.8.8-404YCiJ2agdDxJGZ4AybXg text-1.2.5.0
    time-compat-1.9.6.1-Cd4ZO0rf1QSALzCGMKTb3h transformers-0.5.6.2
    unordered-containers-0.2.20-4hqmnCstShmJXjUlp61Lcu
    uuid-types-1.0.5.1-EtLF0k28bNc38E21nOo17r

haddock-interfaces:
    /usr/share/doc/haskell-http-api-data/html/http-api-data.haddock

haddock-html:         /usr/share/doc/haskell-http-api-data/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
